#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.MainForm;
using System;
using System.Windows.Forms;

namespace HeuristicLab.Core.Networks.Views {
  [View("ParameterizedPort View")]
  [Content(typeof(ParameterizedPort), true)]
  [Content(typeof(IParameterizedPort), false)]
  public partial class ParameterizedPortView : PortView {
    public new IParameterizedPort Content {
      get { return (IParameterizedPort)base.Content; }
      set { base.Content = value; }
    }

    public ParameterizedPortView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.InterfaceChanged -= Content_InterfaceChanged;
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.InterfaceChanged += Content_InterfaceChanged;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      portParameterCollectionView.Content = Content == null ? null : Content.Parameters;
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      portParameterCollectionView.Enabled = Content != null && !ReadOnly;
    }

    protected virtual void Content_InterfaceChanged(object sender, EventArgs e) { }
  }
}
